from tornado.web import RequestHandler
from tornado.httpclient import AsyncHTTPClient
from base.django_handler_mixin import DjangoHandlerMixin

ALLOWED_DOMAINS = {
    "search.gesis.org": True,
    "api.datacite.org": True,
    "www.bioinformatics.org": True,
}


class Proxy(DjangoHandlerMixin, RequestHandler):
    async def get(self, url):
        user = self.get_current_user()
        domain = url.split("/")[2]
        if domain not in ALLOWED_DOMAINS or not user.is_authenticated:
            self.set_status(401)
            self.finish()
            return
        query = self.request.query
        if query:
            url += "?" + query
        http = AsyncHTTPClient()
        response = await http.fetch(url, method="GET", request_timeout=120)
        if not response.error:
            self.write(response.body)
        self.finish()



import time

from selenium.webdriver.common.by import By
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from testing.testcases import LiveTornadoTestCase
from testing.selenium_helper import SeleniumHelper


class CitationImportTest(LiveTornadoTestCase, SeleniumHelper):
    fixtures = ["initial_documenttemplates.json", "initial_styles.json"]

    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.base_url = cls.live_server_url
        driver_data = cls.get_drivers(1)
        cls.driver = driver_data["drivers"][0]
        cls.client = driver_data["clients"][0]
        cls.driver.implicitly_wait(driver_data["wait_time"])
        cls.wait_time = driver_data["wait_time"]

    @classmethod
    def tearDownClass(cls):
        cls.driver.quit()
        super().tearDownClass()

    def setUp(self):
        self.user = self.create_user(
            username="Yeti", email="yeti@snowman.com", passtext="otter1"
        )

    def test_import_on_bibliography_page(self):
        self.login_user(self.user, self.driver, self.client)
        self.driver.get(self.base_url + "/bibliography")
        self.driver.find_element(
            By.XPATH, '//*[normalize-space()="Import from Database"]'
        ).click()
        self.driver.find_element(By.ID, "bibimport-enable-crossref").click()
        self.driver.find_element(By.ID, "bibimport-search-text").send_keys(
            "Money"
        )
        time.sleep(5)
        WebDriverWait(self.driver, 5).until(
            EC.element_to_be_clickable((By.CSS_SELECTOR, "button.api-import"))
        ).click()
        self.assertEqual(
            len(
                self.driver.find_elements(
                    By.CSS_SELECTOR, ".edit-bib.fw-link-text"
                )
            ),
            1,
        )

    def test_import_in_editor(self):
        self.login_user(self.user, self.driver, self.client)
        self.driver.get(self.base_url + "/")
        WebDriverWait(self.driver, self.wait_time).until(
            EC.element_to_be_clickable(
                (By.CSS_SELECTOR, ".new_document button")
            )
        ).click()
        WebDriverWait(self.driver, self.wait_time).until(
            EC.presence_of_element_located((By.CLASS_NAME, "editor-toolbar"))
        )
        self.driver.find_element(By.CSS_SELECTOR, ".article-body").click()
        self.driver.find_element(
            By.CSS_SELECTOR, 'button[title="Cite"]'
        ).click()
        self.driver.find_element(
            By.XPATH, '//*[normalize-space()="Import from database"]'
        ).click()
        self.driver.find_element(By.ID, "bibimport-enable-gesis").click()
        self.driver.find_element(By.ID, "bibimport-search-text").send_keys(
            "Fish"
        )
        WebDriverWait(self.driver, 5).until(
            EC.element_to_be_clickable((By.CSS_SELECTOR, "button.api-import"))
        ).click()
        self.assertEqual(
            len(self.driver.find_elements(By.CSS_SELECTOR, "span.delete")), 1
        )
        self.driver.find_element(
            By.XPATH, '//*[normalize-space()="Insert"]'
        ).click()
        self.assertEqual(
            len(self.driver.find_elements(By.CSS_SELECTOR, "span.citation")), 1
        )
        # Edit editor explicitly
        self.driver.get(self.base_url + "/")
        time.sleep(1)



import os
from glob import glob
from setuptools import find_namespace_packages, setup
from setuptools.command.build_py import build_py as _build_py

# From https://github.com/pypa/setuptools/pull/1574
class build_py(_build_py):
    def find_package_modules(self, package, package_dir):
        modules = super().find_package_modules(package, package_dir)
        patterns = self._get_platform_patterns(
            self.exclude_package_data,
            package,
            package_dir,
        )

        excluded_module_files = []
        for pattern in patterns:
            excluded_module_files.extend(glob(pattern))

        for f in excluded_module_files:
            for module in modules:
                if module[2] == f:
                    modules.remove(module)
        return modules

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='fiduswriter-citation-api-import',
    version='3.11.0',
    packages=find_namespace_packages(),
    include_package_data=True,
    exclude_package_data={
        "": ["configuration.py", "django-admin.py", "build/*"]
    },
    license='AGPL License',
    description='A Fidus Writer plugin to import citations via API.',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://www.github.org/fiduswriter/fiduswriter-citation-api-import',
    author='Johannes Wilm',
    author_email='johannes@fiduswriter.org',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 4.1',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Affero General Public License v3',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    cmdclass={'build_py': build_py}
)
